Revision: 1997
Author: olavmrk
Date: Wed Nov 18 00:15:05 2009
Log: Auth_Simple: Extend to allow generic parameters to be passed to  
requireAuth.
http://code.google.com/p/simplesamlphp/source/detail?r=1997

Modified:
  /trunk/lib/SimpleSAML/Auth/Simple.php

=======================================
--- /trunk/lib/SimpleSAML/Auth/Simple.php       Mon Oct 26 08:14:28 2009
+++ /trunk/lib/SimpleSAML/Auth/Simple.php       Wed Nov 18 00:15:05 2009
@@ -53,13 +53,16 @@
         * user with the authentication source, and then return the user to the
         * current page.
         *
-        * If $allowPost is set to TRUE, any POST data to the current page is
-        * preserved. If $allowPost is FALSE, the user will be returned to the
-        * current page with a GET request.
+        * This function accepts an array $params, which controls some parts of
+        * the authentication. The accepted parameters depends on the  
authentication
+        * source being used. Some parameters are generic:
+        *  - 'KeepPost': If the current request is a POST request, keep the 
POST
+        *    data until after the authentication.
+        *  - 'ReturnTo': The URL the user should be returned to after  
authentication.
         *
         * @param array $options  Various options to the authentication request.
         */
-       public function requireAuth(array $options = array()) {
+       public function requireAuth(array $params = array()) {

                $session = SimpleSAML_Session::getInstance();

@@ -68,14 +71,14 @@
                        return;
                }

-               if (array_key_exists('KeepPost', $options)) {
-                       $keepPost = (bool)$options['KeepPost'];
+               if (array_key_exists('KeepPost', $params)) {
+                       $keepPost = (bool)$params['KeepPost'];
                } else {
                        $keepPost = TRUE;
                }

-               if (array_key_exists('ReturnTo', $options)) {
-                       $returnTo = (string)$options['ReturnTo'];
+               if (array_key_exists('ReturnTo', $params)) {
+                       $returnTo = (string)$params['ReturnTo'];
                } else {
                        $returnTo = SimpleSAML_Utilities::selfURL();
                }
@@ -90,11 +93,9 @@
                 */
                $restartURL = $this->getLoginURL($returnTo);

-               $hints = array(
-                       SimpleSAML_Auth_State::RESTART => $restartURL,
-               );
-
-               SimpleSAML_Auth_Default::initLogin($this->authSource, 
$returnTo, NULL,  
$hints);
+               $params[SimpleSAML_Auth_State::RESTART] = $restartURL;
+
+               SimpleSAML_Auth_Default::initLogin($this->authSource, 
$returnTo, NULL,  
$params);
        }
@@ -53,13 +53,16 @@
authentication.
         *
-        * @param array $options  Various options to the authentication request.
+        * @param array $params  Various options to the authentication request.
         */


--

You received this message because you are subscribed to the Google Groups 
"simpleSAMLphp commits" group.
To post to this group, send email to [email protected].
For more options, visit this group at 
http://groups.google.com/group/simplesamlphp-commits?hl=.


Reply via email to